# Suggerimenti per migliorare le traduzioni della documentazione

Grazie per il tuo interesse in questo progetto! La documentazione non in inglese è tradotta automaticamente da modelli linguistici di grandi dimensioni, quindi gli errori sono inevitabili. Se noti problemi in una lingua con cui hai familiarità, ti diamo il benvenuto a suggerire miglioramenti.

Prima di iniziare a contribuire, ti invitiamo a leggere la seguente guida per aiutare a garantire che i tuoi suggerimenti possano essere accettati senza problemi.

# Invia suggerimenti tramite Weblate

Utilizziamo [Weblate](https://weblate.org/) per gestire le traduzioni della nostra documentazione. Puoi verificare lo stato attuale della traduzione e inviare suggerimenti sulla [pagina Weblate del progetto](https://hosted.weblate.org/projects/pdfmathtranslate-next/).

## Come inviare un suggerimento

È molto semplice proporre miglioramenti alle traduzioni tramite Weblate, e non è nemmeno necessario registrare un account. Continua a leggere per il processo passo dopo passo.

Supponi di voler migliorare la prima frase nella sezione "命令行参数" di [高级选项 → 高级](docs/en/advanced/advanced.md):

1. Apri la [pagina Weblate del progetto](https://hosted.weblate.org/projects/pdfmathtranslate-next/).

2. Clicca `Search` in alto.

<img src="./../../images/weblate/homepage.png" width="420px" alt="homepage"/>

3. In "Filtro", inserisci il segmento di testo che desideri trovare. Anche un testo parziale va bene.

<img src="./../../images/weblate/search.png" alt="search"/>

Quando hai finito, premi <kbd>Enter</kbd>.

4. Dopo aver premuto <kbd>Invio</kbd>, verrai portato alla pagina dei risultati di ricerca. Clicca sul risultato che preferisci per aprire la vista di modifica.

<img src="./../../images/weblate/search-result.png" alt="search result"/>

5. Nella vista di modifica, apporta le tue modifiche alla traduzione. Una volta terminato, fai clic su <kbd>Suggerisci</kbd>. Tutto qui: hai completato con successo un contributo.

<img src="./../../images/weblate/suggestion.png" alt="suggestion"/>

Esamineremo il tuo suggerimento dopo che sarà stato inviato. Una volta approvato, le tue modifiche appariranno nella documentazione.

<div align="right"> 
<h6><small>Parte del contenuto di questa pagina è stata tradotta da GPT e potrebbe contenere errori.</small></h6>